==> jc-1.4.0.tar.gz: soot/jimple/spark/sets/DoublePointsToSet__242.h <==
// class soot.jimple.spark.sets.DoublePointsToSet$2

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 89999a318a61acba soot_jimple_spark_sets_DoublePointsToSet__242
// @dep_class 4af9fec835f92d51 soot_jimple_spark_sets_P2SetFactory

// header file dependencies
// @dep_header soot_jimple_spark_sets_P2SetFactory

#include "soot/jimple/spark/sets/P2SetFactory.h"

#ifndef _JC_soot_jimple_spark_sets_DoublePointsToSet__242_H_
#define _JC_soot_jimple_spark_sets_DoublePointsToSet__242_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_spark_pag_PAG$object;
struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$sub_refs	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$sub_refs;
typedef struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$sub_nonrefs	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$refs	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$refs;
typedef struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$nonrefs	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$nonrefs;
typedef struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$object	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$object;

typedef const struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$vmethods	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$vmethods;
typedef const struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$vtable	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$vtable;
typedef const struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$vtype	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$vtype;

// Constructors
extern void _jc_soot_jimple_spark_sets_DoublePointsToSet__242$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$object *);

// Virtual methods
extern struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object *_jc_soot_jimple_spark_sets_DoublePointsToSet__242$method$newSet$774f6a02bfa5ba98(_jc_env *, struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$object *, struct _jc_soot_Type$object *, struct _jc_soot_jimple_spark_pag_PAG$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_sets_DoublePointsToSet__242$method_info$newSet$774f6a02bfa5ba98;

// Virtual methods structure
struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$vmethods {
	struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object	*(*newSet$774f6a02bfa5ba98)(_jc_env *, struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$object *, struct _jc_soot_Type$object *, struct _jc_soot_jimple_spark_pag_PAG$object *);
};

// Vtable
struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_sets_P2SetFactory$vmethods	soot_jimple_spark_sets_P2SetFactory;
	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$vmethods	soot_jimple_spark_sets_DoublePointsToSet__242;
};

// Vtype
struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$refs {
    _jc_soot_jimple_spark_sets_DoublePointsToSet__242$sub_refs	soot_jimple_spark_sets_DoublePointsToSet__242;
    _jc_soot_jimple_spark_sets_P2SetFactory$sub_refs	soot_jimple_spark_sets_P2SetFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_sets_P2SetFactory$sub_nonrefs	soot_jimple_spark_sets_P2SetFactory;
    _jc_soot_jimple_spark_sets_DoublePointsToSet__242$sub_nonrefs	soot_jimple_spark_sets_DoublePointsToSet__242;
};

// Object instance structure
struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$object {
	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$vtype	*vtype;
	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_sets_DoublePointsToSet__242$vtype _jc_soot_jimple_spark_sets_DoublePointsToSet__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_sets_DoublePointsToSet__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_sets_DoublePointsToSet__242$class_object;

#endif	/* _JC_soot_jimple_spark_sets_DoublePointsToSet__242_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/sets/DoublePointsToSet__242.h <==
// class soot.jimple.spark.sets.DoublePointsToSet$2

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 89999a318a61acba soot_jimple_spark_sets_DoublePointsToSet__242
// @dep_class 4af9fec835f92d51 soot_jimple_spark_sets_P2SetFactory

// header file dependencies
// @dep_header soot_jimple_spark_sets_P2SetFactory

#include "soot/jimple/spark/sets/P2SetFactory.h"

#ifndef _JC_soot_jimple_spark_sets_DoublePointsToSet__242_H_
#define _JC_soot_jimple_spark_sets_DoublePointsToSet__242_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_spark_pag_PAG$object;
struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$sub_refs	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$sub_refs;
typedef struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$sub_nonrefs	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$refs	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$refs;
typedef struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$nonrefs	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$nonrefs;
typedef struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$object	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$object;

typedef const struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$vmethods	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$vmethods;
typedef const struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$vtable	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$vtable;
typedef const struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$vtype	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$vtype;

// Constructors
extern void _jc_soot_jimple_spark_sets_DoublePointsToSet__242$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object *_jc_soot_jimple_spark_sets_DoublePointsToSet__242$method$newSet$774f6a02bfa5ba98(_jc_env *, struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$object *, struct _jc_soot_Type$object *, struct _jc_soot_jimple_spark_pag_PAG$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_sets_DoublePointsToSet__242$method_info$newSet$774f6a02bfa5ba98;

// Virtual methods structure
struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$vmethods {
	struct _jc_soot_jimple_spark_sets_PointsToSetInternal$object	*(*newSet$774f6a02bfa5ba98)(_jc_env *, struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$object *, struct _jc_soot_Type$object *, struct _jc_soot_jimple_spark_pag_PAG$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_sets_P2SetFactory$vmethods	soot_jimple_spark_sets_P2SetFactory;
	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$vmethods	soot_jimple_spark_sets_DoublePointsToSet__242;
};

// Vtype
struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$refs {
    _jc_soot_jimple_spark_sets_DoublePointsToSet__242$sub_refs	soot_jimple_spark_sets_DoublePointsToSet__242;
    _jc_soot_jimple_spark_sets_P2SetFactory$sub_refs	soot_jimple_spark_sets_P2SetFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_sets_P2SetFactory$sub_nonrefs	soot_jimple_spark_sets_P2SetFactory;
    _jc_soot_jimple_spark_sets_DoublePointsToSet__242$sub_nonrefs	soot_jimple_spark_sets_DoublePointsToSet__242;
};

// Object instance structure
struct _jc_soot_jimple_spark_sets_DoublePointsToSet__242$object {
	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$vtype	*vtype;
	_jc_soot_jimple_spark_sets_DoublePointsToSet__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_sets_DoublePointsToSet__242$vtype _jc_soot_jimple_spark_sets_DoublePointsToSet__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_sets_DoublePointsToSet__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_sets_DoublePointsToSet__242$class_object;

#endif	/* _JC_soot_jimple_spark_sets_DoublePointsToSet__242_H_ */
